#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 byteorder
version:              1.0.4
visibility:           public
id:                   byteorder-1.0.4-IFlP2E44NdRWUzguGw0c2
key:                  byteorder-1.0.4-IFlP2E44NdRWUzguGw0c2
license:              BSD-3-Clause
maintainer:           Antoine Latter <aslatter@gmail.com>
author:               Antoine Latter
homepage:             http://community.haskell.org/~aslatter/code/byteorder
synopsis:
    Exposes the native endianness or byte ordering of the system.

description:
    This package is for working with the native byte-ordering of
    the system.

category:             System
abi:                  aa0f9fc5cceaef94662902c948bc6cfc
exposed:              True
exposed-modules:      System.ByteOrder
import-dirs:          /usr/lib/ghc-9.6.6/site-local/byteorder-1.0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/byteorder-1.0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/byteorder-1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-byteorder
hs-libraries:         HSbyteorder-1.0.4-IFlP2E44NdRWUzguGw0c2
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-byteorder/html/byteorder.haddock
haddock-html:         /usr/share/doc/haskell-byteorder/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

